@@ -14,23 +14,22 @@
 #' @return interval estimate of a 95\% confidence interval for each estimate parameters associated with the model.
 #' @return Deviance the deviance associated with the model.
 #' @references Carlos A. Cardozo, G. Paula and L. Vanegas. Semi-parametric accelerated failure time models with generalized log-gamma erros. In preparation.
-#' @references Carlos Alberto Cardozo Delgado, Semi-parametric generalized log-gamma regression models. Ph. D. thesis. Sao Paulo University.
 #' @author Carlos Alberto Cardozo Delgado <cardozorpackages@gmail.com>, G. Paula and L. Vanegas.
 #' @examples
 #' rows  <- 240
-#' columns <- 3
-#' t_beta  <- c(0.7, 0.5, 2)
-#' t_sigma <- 1.5
-#' t_lambda <- sigma
+#' columns <- 2
+#' t_beta  <- c(0.5, 2)
+#' t_sigma <- 1
+#' t_lambda <- 1
 #' set.seed(8142031)
 #' library(ssym)
-#' x2 <- rbinom(rows, 1, 0.5)
-#' x3 <- runif(rows, 0, 1)
-#' X <- cbind(1,x2,x3)
+#' x1 <- rbinom(rows, 1, 0.5)
+#' x2 <- runif(columns, 0, 1)
+#' X <- cbind(x1,x2)
 #' s         <- t_sigma^2
 #' a         <- 1/s
 #' t_ini1    <- exp(X %*% t_beta) * rgamma(rows, scale = s, shape = a)
-#' cens.time <- rweibull(rows, 0.4, 14)
+#' cens.time <- rweibull(rows, 0.3, 14)
 #' delta1     <- ifelse(t_ini1 > cens.time, 1, 0)
 #' obst1 <- t_ini1
 #' for (i in 1:rows) {
@@ -39,7 +38,7 @@
 #'   }
 #' }
 #' data.example <- data.frame(obst1,delta1,X)
-#' fit3 <- survglg(Surv(log(obst1),delta1) ~ x2 + x3 , data=data.example,shape=1)
+#' fit3 <- survglg(Surv(log(obst1),delta1) ~ x1 + x2 - 1, data=data.example,shape=0.9)
 #' summary(fit3)
 #' plot(fit3)
 #' @import Formula
@@ -341,6 +340,7 @@ survglg = function(formula, data, shape, Maxiter, Tolerance) {
         llglg <- loglikglg(output[1:p], output[(p + 1)], lambda0)
         aic <- -2 * llglg + 2 * (p + 1)
         bic <- -2 * llglg + log(n) * (p + 1)
+        aic2 <- aic + 2 * sum(y)
         scores <- U_theta(output[1:p], output[p + 1], lambda0)
         covar <- matrix(0, p + 1, p + 1)
         covar <- I_tetha(output[1:p], output[p + 1], lambda0)
@@ -375,7 +375,8 @@ survglg = function(formula, data, shape, Maxiter, Tolerance) {
             p = p, mu = output[1:p], sigma = output[p + 1], lambda = lambda0,
             y = Y[, 1], delta = Delta, X_bar = X, y_est = y_est, rord = ordresidual,
             rdev = dev, deviance = devian, modelsurv=msurv, survItheta = scovar, scores = scores,
-            goodnessoffit = good_fit, llglg = llglg, AIC = aic, BIC = bic, st_error = ste, z_values = zs, p.values = pval,
+            goodnessoffit = good_fit, llglg = llglg, AIC = aic, BIC = bic,
+            AIC2 = aic2, st_error = ste, z_values = zs, p.values = pval,
             interval = inter, convergence = conv, condition = condition,
             Iterations = iter, semi = FALSE, censored = TRUE)
         class(output) = "sglg"
